# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_session_view_response import FlowSessionViewResponse

class TestFlowSessionViewResponse(unittest.TestCase):
    """FlowSessionViewResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowSessionViewResponse:
        """Test FlowSessionViewResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowSessionViewResponse`
        """
        model = FlowSessionViewResponse()
        if include_optional:
            return FlowSessionViewResponse(
                session_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                chatbot_id = '',
                flow_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                workspace_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_msg_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                msg_count = 56,
                credits = 56,
                chatbot_name = '',
                flow_name = '',
                tags = [
                    ''
                    ],
                duration = 56,
                ipaddress = '',
                url = ''
            )
        else:
            return FlowSessionViewResponse(
                session_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                flow_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                workspace_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testFlowSessionViewResponse(self):
        """Test FlowSessionViewResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.flow_config import FlowConfig
from flowhunt.models.flow_type import FlowType
from typing import Optional, Set
from typing_extensions import Self

class FlowDetailResponse(BaseModel):
    """
    FlowDetailResponse
    """ # noqa: E501
    id: StrictStr = Field(description="Flow ID")
    name: StrictStr = Field(description="Flow name")
    description: StrictStr = Field(description="Flow description")
    detailed_description: Optional[StrictStr] = None
    config: FlowConfig = Field(description="Flow configuration")
    flow_type: FlowType = Field(description="Flow type")
    executed_at: Optional[datetime] = None
    category_id: Optional[StrictStr] = None
    branch: StrictStr = Field(description="Flow branch")
    enable_cache: StrictBool = Field(description="Enable cache")
    draft_version_nr: Optional[StrictInt] = None
    prod_version_nr: Optional[StrictInt] = None
    last_modified: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["id", "name", "description", "detailed_description", "config", "flow_type", "executed_at", "category_id", "branch", "enable_cache", "draft_version_nr", "prod_version_nr", "last_modified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlowDetailResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict['config'] = self.config.to_dict()
        # set to None if detailed_description (nullable) is None
        # and model_fields_set contains the field
        if self.detailed_description is None and "detailed_description" in self.model_fields_set:
            _dict['detailed_description'] = None

        # set to None if executed_at (nullable) is None
        # and model_fields_set contains the field
        if self.executed_at is None and "executed_at" in self.model_fields_set:
            _dict['executed_at'] = None

        # set to None if category_id (nullable) is None
        # and model_fields_set contains the field
        if self.category_id is None and "category_id" in self.model_fields_set:
            _dict['category_id'] = None

        # set to None if draft_version_nr (nullable) is None
        # and model_fields_set contains the field
        if self.draft_version_nr is None and "draft_version_nr" in self.model_fields_set:
            _dict['draft_version_nr'] = None

        # set to None if prod_version_nr (nullable) is None
        # and model_fields_set contains the field
        if self.prod_version_nr is None and "prod_version_nr" in self.model_fields_set:
            _dict['prod_version_nr'] = None

        # set to None if last_modified (nullable) is None
        # and model_fields_set contains the field
        if self.last_modified is None and "last_modified" in self.model_fields_set:
            _dict['last_modified'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlowDetailResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "detailed_description": obj.get("detailed_description"),
            "config": FlowConfig.from_dict(obj["config"]) if obj.get("config") is not None else None,
            "flow_type": obj.get("flow_type"),
            "executed_at": obj.get("executed_at"),
            "category_id": obj.get("category_id"),
            "branch": obj.get("branch"),
            "enable_cache": obj.get("enable_cache"),
            "draft_version_nr": obj.get("draft_version_nr"),
            "prod_version_nr": obj.get("prod_version_nr"),
            "last_modified": obj.get("last_modified")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.general_mcp_subserver_response import GeneralMCPSubserverResponse

class TestGeneralMCPSubserverResponse(unittest.TestCase):
    """GeneralMCPSubserverResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeneralMCPSubserverResponse:
        """Test GeneralMCPSubserverResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeneralMCPSubserverResponse`
        """
        model = GeneralMCPSubserverResponse()
        if include_optional:
            return GeneralMCPSubserverResponse(
                server_id = '0x1d230dabdb5bc7cb',
                name = 'My MCP Subserver',
                description = '',
                status = 'active',
                icon = '',
                version = '1.0.0',
                capabilities = [
                    flowhunt.models.general_mcp_subserver_capabilities_response.GeneralMCPSubserverCapabilitiesResponse(
                        capability_id = '0x1d230dabdb5bc7cb', 
                        name = 'Data Processing', 
                        description = '', )
                    ],
                integration_slug = 'shopify_integration'
            )
        else:
            return GeneralMCPSubserverResponse(
                server_id = '0x1d230dabdb5bc7cb',
                name = 'My MCP Subserver',
                status = 'active',
                version = '1.0.0',
                integration_slug = 'shopify_integration',
        )
        """

    def testGeneralMCPSubserverResponse(self):
        """Test GeneralMCPSubserverResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.google_ads_customer_update_request import GoogleAdsCustomerUpdateRequest

class TestGoogleAdsCustomerUpdateRequest(unittest.TestCase):
    """GoogleAdsCustomerUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleAdsCustomerUpdateRequest:
        """Test GoogleAdsCustomerUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleAdsCustomerUpdateRequest`
        """
        model = GoogleAdsCustomerUpdateRequest()
        if include_optional:
            return GoogleAdsCustomerUpdateRequest(
                language_code = '',
                country = '',
                min_queries = 56,
                cluster_strength = 56,
                min_impressions = 56,
                min_clicks = 56,
                process_negative_keywords = 'Y',
                cron_settings = '',
                action_type = 'I',
                ga_measurement_id = '',
                ga_api_secret = ''
            )
        else:
            return GoogleAdsCustomerUpdateRequest(
        )
        """

    def testGoogleAdsCustomerUpdateRequest(self):
        """Test GoogleAdsCustomerUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SerpClusterGroupIntersectionsRequest(BaseModel):
    """
    SerpClusterGroupIntersectionsRequest
    """ # noqa: E501
    customer_id: StrictStr = Field(description="Customer ID of cluster")
    campaign_id: Optional[StrictStr] = None
    group_id: Optional[StrictStr] = None
    min_cluster_strength: Optional[StrictInt] = None
    suggest_other_matching_keywords: Optional[StrictBool] = None
    include_negative_keywords: Optional[StrictBool] = None
    include_all_members: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["customer_id", "campaign_id", "group_id", "min_cluster_strength", "suggest_other_matching_keywords", "include_negative_keywords", "include_all_members"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SerpClusterGroupIntersectionsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if campaign_id (nullable) is None
        # and model_fields_set contains the field
        if self.campaign_id is None and "campaign_id" in self.model_fields_set:
            _dict['campaign_id'] = None

        # set to None if group_id (nullable) is None
        # and model_fields_set contains the field
        if self.group_id is None and "group_id" in self.model_fields_set:
            _dict['group_id'] = None

        # set to None if min_cluster_strength (nullable) is None
        # and model_fields_set contains the field
        if self.min_cluster_strength is None and "min_cluster_strength" in self.model_fields_set:
            _dict['min_cluster_strength'] = None

        # set to None if suggest_other_matching_keywords (nullable) is None
        # and model_fields_set contains the field
        if self.suggest_other_matching_keywords is None and "suggest_other_matching_keywords" in self.model_fields_set:
            _dict['suggest_other_matching_keywords'] = None

        # set to None if include_negative_keywords (nullable) is None
        # and model_fields_set contains the field
        if self.include_negative_keywords is None and "include_negative_keywords" in self.model_fields_set:
            _dict['include_negative_keywords'] = None

        # set to None if include_all_members (nullable) is None
        # and model_fields_set contains the field
        if self.include_all_members is None and "include_all_members" in self.model_fields_set:
            _dict['include_all_members'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SerpClusterGroupIntersectionsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customer_id": obj.get("customer_id"),
            "campaign_id": obj.get("campaign_id"),
            "group_id": obj.get("group_id"),
            "min_cluster_strength": obj.get("min_cluster_strength"),
            "suggest_other_matching_keywords": obj.get("suggest_other_matching_keywords"),
            "include_negative_keywords": obj.get("include_negative_keywords"),
            "include_all_members": obj.get("include_all_members")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_session_event import FlowSessionEvent

class TestFlowSessionEvent(unittest.TestCase):
    """FlowSessionEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowSessionEvent:
        """Test FlowSessionEvent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowSessionEvent`
        """
        model = FlowSessionEvent()
        if include_optional:
            return FlowSessionEvent(
                workspace_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                session_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                event_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                event_type = text,
                created_at_timestamp = '',
                action_type = loading,
                credits = 10,
                metadata = None,
                component_name = ''
            )
        else:
            return FlowSessionEvent(
                workspace_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                session_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                event_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                event_type = text,
                created_at_timestamp = '',
                action_type = loading,
                credits = 10,
        )
        """

    def testFlowSessionEvent(self):
        """Test FlowSessionEvent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.credits_api import CreditsApi


class TestCreditsApi(unittest.TestCase):
    """CreditsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CreditsApi()

    def tearDown(self) -> None:
        pass

    def test_get_credit_balance(self) -> None:
        """Test case for get_credit_balance

        Get Credit Balance
        """
        pass

    def test_get_workspace_credit_balance(self) -> None:
        """Test case for get_workspace_credit_balance

        Get Workspace Credit Balance
        """
        pass

    def test_search_credit_transactions(self) -> None:
        """Test case for search_credit_transactions

        Search Credit Transactions
        """
        pass

    def test_search_daily_credit_transactions(self) -> None:
        """Test case for search_daily_credit_transactions

        Search Daily Credit Transactions
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.api_keys_api import ApiKeysApi


class TestApiKeysApi(unittest.TestCase):
    """ApiKeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApiKeysApi()

    def tearDown(self) -> None:
        pass

    def test_create_api_key(self) -> None:
        """Test case for create_api_key

        Create Api Key
        """
        pass

    def test_delete_api_key(self) -> None:
        """Test case for delete_api_key

        Delete Api Key
        """
        pass

    def test_search_api_key(self) -> None:
        """Test case for search_api_key

        Search Api Key
        """
        pass

    def test_update_api_key(self) -> None:
        """Test case for update_api_key

        Update Api Key
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.tracking_event_create_request import TrackingEventCreateRequest
from typing import Optional, Set
from typing_extensions import Self

class TrackingEventCreateRequests(BaseModel):
    """
    TrackingEventCreateRequests
    """ # noqa: E501
    events: List[TrackingEventCreateRequest] = Field(description="The list of events to be created")
    unique_id: Optional[StrictStr] = None
    fp: Optional[StrictStr] = None
    session_id: Optional[StrictStr] = None
    with_address: Optional[StrictBool] = None
    ga: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["events", "unique_id", "fp", "session_id", "with_address", "ga"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TrackingEventCreateRequests from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in events (list)
        _items = []
        if self.events:
            for _item_events in self.events:
                if _item_events:
                    _items.append(_item_events.to_dict())
            _dict['events'] = _items
        # set to None if unique_id (nullable) is None
        # and model_fields_set contains the field
        if self.unique_id is None and "unique_id" in self.model_fields_set:
            _dict['unique_id'] = None

        # set to None if fp (nullable) is None
        # and model_fields_set contains the field
        if self.fp is None and "fp" in self.model_fields_set:
            _dict['fp'] = None

        # set to None if session_id (nullable) is None
        # and model_fields_set contains the field
        if self.session_id is None and "session_id" in self.model_fields_set:
            _dict['session_id'] = None

        # set to None if with_address (nullable) is None
        # and model_fields_set contains the field
        if self.with_address is None and "with_address" in self.model_fields_set:
            _dict['with_address'] = None

        # set to None if ga (nullable) is None
        # and model_fields_set contains the field
        if self.ga is None and "ga" in self.model_fields_set:
            _dict['ga'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TrackingEventCreateRequests from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "events": [TrackingEventCreateRequest.from_dict(_item) for _item in obj["events"]] if obj.get("events") is not None else None,
            "unique_id": obj.get("unique_id"),
            "fp": obj.get("fp"),
            "session_id": obj.get("session_id"),
            "with_address": obj.get("with_address"),
            "ga": obj.get("ga")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class IntegrationSlug(str, Enum):
    """
    IntegrationSlug
    """

    """
    allowed enum values
    """
    SHOPIFY_INTEGRATION = 'shopify_integration'
    SLACK_INTEGRATION = 'slack_integration'
    HUBSPOT_INTEGRATION = 'hubspot_integration'
    LIVEAGENT_INTEGRATION = 'liveagent_integration'
    HUBSPOT_WIDGET_INTEGRATION = 'hubspot_widget_integration'
    LIVECHAT_INTEGRATION = 'livechat_integration'
    SMARTSUPP_INTEGRATION = 'smartsupp_integration'
    FRESHCHAT_INTEGRATION = 'freshchat_integration'
    TAWK_INTEGRATION = 'tawk_integration'
    GOOGLE_INTEGRATION = 'google_integration'
    WORDPRESS_INTEGRATION = 'wordpress_integration'
    GMAIL_INTEGRATION = 'gmail_integration'
    INSTAGRAM_INTEGRATION = 'instagram_integration'
    MICROSOFT_OUTLOOK_INTEGRATION = 'microsoft_outlook_integration'
    ODOO_INTEGRATION = 'odoo_integration'
    GOOGLE_CALENDAR_INTEGRATION = 'google_calendar_integration'
    GOOGLE_ADS_INTEGRATION = 'google_ads_integration'
    GOOGLE_DOCS_INTEGRATION = 'google_docs_integration'
    GOOGLE_DRIVE_INTEGRATION = 'google_drive_integration'
    GOOGLE_SHEETS_INTEGRATION = 'google_sheets_integration'
    GOOGLE_TASKS_INTEGRATION = 'google_tasks_integration'
    GOOGLE_MEET_INTEGRATION = 'google_meet_integration'
    GOOGLE_SLIDES_INTEGRATION = 'google_slides_integration'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of IntegrationSlug from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.aspec_ratio import AspecRatio
from flowhunt.models.base_foundation_model import BaseFoundationModel
from typing import Optional, Set
from typing_extensions import Self

class InferenceHistorySearchRequest(BaseModel):
    """
    InferenceHistorySearchRequest
    """ # noqa: E501
    from_date: Optional[datetime] = None
    to_date: Optional[datetime] = None
    limit: Optional[StrictInt] = Field(default=10, description="The number of results to return")
    search_after: Optional[List[Any]] = None
    base_model: Optional[BaseFoundationModel] = None
    style: Optional[StrictStr] = None
    effect: Optional[StrictStr] = None
    aspect_ratio: Optional[AspecRatio] = None
    __properties: ClassVar[List[str]] = ["from_date", "to_date", "limit", "search_after", "base_model", "style", "effect", "aspect_ratio"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InferenceHistorySearchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if from_date (nullable) is None
        # and model_fields_set contains the field
        if self.from_date is None and "from_date" in self.model_fields_set:
            _dict['from_date'] = None

        # set to None if to_date (nullable) is None
        # and model_fields_set contains the field
        if self.to_date is None and "to_date" in self.model_fields_set:
            _dict['to_date'] = None

        # set to None if search_after (nullable) is None
        # and model_fields_set contains the field
        if self.search_after is None and "search_after" in self.model_fields_set:
            _dict['search_after'] = None

        # set to None if base_model (nullable) is None
        # and model_fields_set contains the field
        if self.base_model is None and "base_model" in self.model_fields_set:
            _dict['base_model'] = None

        # set to None if style (nullable) is None
        # and model_fields_set contains the field
        if self.style is None and "style" in self.model_fields_set:
            _dict['style'] = None

        # set to None if effect (nullable) is None
        # and model_fields_set contains the field
        if self.effect is None and "effect" in self.model_fields_set:
            _dict['effect'] = None

        # set to None if aspect_ratio (nullable) is None
        # and model_fields_set contains the field
        if self.aspect_ratio is None and "aspect_ratio" in self.model_fields_set:
            _dict['aspect_ratio'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InferenceHistorySearchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "from_date": obj.get("from_date"),
            "to_date": obj.get("to_date"),
            "limit": obj.get("limit") if obj.get("limit") is not None else 10,
            "search_after": obj.get("search_after"),
            "base_model": obj.get("base_model"),
            "style": obj.get("style"),
            "effect": obj.get("effect"),
            "aspect_ratio": obj.get("aspect_ratio")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.youtube_transcript_response import YoutubeTranscriptResponse

class TestYoutubeTranscriptResponse(unittest.TestCase):
    """YoutubeTranscriptResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> YoutubeTranscriptResponse:
        """Test YoutubeTranscriptResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `YoutubeTranscriptResponse`
        """
        model = YoutubeTranscriptResponse()
        if include_optional:
            return YoutubeTranscriptResponse(
                id = '',
                status = 'PENDING',
                result = flowhunt.models.youtube_content.YoutubeContent(
                    url = '', 
                    img_url = '', 
                    status_code = 56, 
                    created_at = 1.337, 
                    published_at = 1.337, 
                    title = '', 
                    doc_name = '', 
                    lang = '', 
                    content_type = '', 
                    encoding = '', 
                    apparent_encoding = '', 
                    description = '', 
                    content = '', 
                    metadata = {
                        'key' : null
                        }, 
                    alt_content = [
                        ''
                        ], 
                    content_hash = '', 
                    author = '', 
                    channel_id = '', 
                    channel_url = '', 
                    channel_title = '', 
                    duration = 56, 
                    keywords = [
                        ''
                        ], 
                    doc_type = 'PDF', 
                    credits = 56, ),
                error_message = ''
            )
        else:
            return YoutubeTranscriptResponse(
                id = '',
                status = 'PENDING',
        )
        """

    def testYoutubeTranscriptResponse(self):
        """Test YoutubeTranscriptResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
